@@ -31,9 +31,16 @@ class Storage(driver.Base):
         self._jss = JssClient(self._access_key, self._secret_key, self._domain, None)
         
     def _init_path(self, path=None):
-        if path:
-            return path.replace("/", ".")
-        return path
+        res = self._rootpath
+        if not path:
+            res = self._rootpath
+        else:
+            if path.startswith(self._rootpath):
+                res = path
+            else:
+                res = os.path.join(self._rootpath, path)
+            
+        return res.replace("/", ".")
 
     def content_redirect_url(self, path):
         logger.info("content_redirect_url path:%s" % path)
